<?php
namespace MW\Concerts\Controller;

/*                                                                        *
 * This script belongs to the FLOW3 package "MW.Concerts".                *
 *                                                                        */

use TYPO3\FLOW3\Annotations as FLOW3;
use MW\Concerts\Domain\Model;

/**
 * 
 * Standard controller for the MW.Concerts package. Renders a list of
 * concerts and provides a debug method for generating dummy data.
 *
 * @FLOW3\Scope("singleton")
 * 
 * @author     Martin Helmich <m.helmich@mittwald.de>
 * @version    2011-10-24
 * @package    MW.Concerts
 * @subpackage Controller
 * 
 */
class StandardController extends \TYPO3\FLOW3\MVC\Controller\ActionController {

	/**
	 * A concert repository.
	 * @FLOW3\Inject
	 * @var \MW\Concerts\Domain\Repository\ConcertRepository
	 */
	protected $concertRepository;

	/**
	 * The index action. Renders a list of all concerts.
	 * @return void
	 */
	public function indexAction() {
		$this->view->assign('concerts', $this->concertRepository->findAll());
	}

	/**
	 * A debug action for generating dummy data.
	 * @return void
	 */
	public function dummyDataAction() {
		$this->concertRepository->removeAll();

		$artist = new Model\Artist();
		$artist->setName('Slayer');
		$artist->setGenre('Thrash Metal');
		$artist->setCountry('USA');

		$concert = new Model\Concert();
		$concert->setArtist($artist);
		$concert->setLocation('Espelkamp');
		$concert->setDate(new \DateTime('2006-06-06'));

		$this->concertRepository->add($concert);
	}
	
}
